Numerical core for the advection-diffusion solver (climlab.dynamics.adv_diff_numerics)
------

.. automodule:: climlab.dynamics.adv_diff_numerics
    :members:
    :private-members:
    :undoc-members:
